==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/system/api/gwt/serder/DomainTemplateGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.system.api.gwt.serder;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class DomainTemplateGwtSerDer implements GwtSerDer<net.bluemind.system.api.DomainTemplate> {

	public DomainTemplateGwtSerDer( ) {
	}

	@Override
	public net.bluemind.system.api.DomainTemplate deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.system.api.DomainTemplate ret = new net.bluemind.system.api.DomainTemplate();
		deserializeTo(ret, json);

		return ret;
	}

	public void deserializeTo(net.bluemind.system.api.DomainTemplate ret, JSONObject json) {

		JSONValue kindsJSON = json.get("kinds");
		ret.kinds =  new GwtSerDerUtils.ListSerDer<>(new net.bluemind.system.api.gwt.serder.DomainTemplateKindGwtSerDer()).deserialize(kindsJSON);
	}

	@Override
	public JSONValue serialize(net.bluemind.system.api.DomainTemplate o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.system.api.DomainTemplate o, JSONObject ret) {

		ret.put("kinds",  new GwtSerDerUtils.ListSerDer<>(new net.bluemind.system.api.gwt.serder.DomainTemplateKindGwtSerDer()).serialize( o.kinds ));
	}
}

==> net.bluemind.p2.platform-5.4.2760.zip: net/bluemind/system/api/gwt/serder/DomainTemplateGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.system.api.gwt.serder;

import java.util.Set;
import java.util.HashSet;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class DomainTemplateGwtSerDer implements GwtSerDer<net.bluemind.system.api.DomainTemplate> {

	public DomainTemplateGwtSerDer( ) {
	}

	@Override
	public net.bluemind.system.api.DomainTemplate deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.system.api.DomainTemplate ret = new net.bluemind.system.api.DomainTemplate();
		deserializeTo(ret, json);
		return ret;
	}

	public void deserializeTo(net.bluemind.system.api.DomainTemplate ret, JSONObject json) {
		JSONValue kindsJSON = json.get("kinds");
		ret.kinds =  new GwtSerDerUtils.ListSerDer<>(new net.bluemind.system.api.gwt.serder.DomainTemplateKindGwtSerDer()).deserialize(kindsJSON);
	}

	public void deserializeTo(net.bluemind.system.api.DomainTemplate ret, JSONObject json, Set<String> childPropertiesToIgnore) {
		if (!childPropertiesToIgnore.contains("kinds")) {
			JSONValue kindsJSON = json.get("kinds");
			ret.kinds =  new GwtSerDerUtils.ListSerDer<>(new net.bluemind.system.api.gwt.serder.DomainTemplateKindGwtSerDer()).deserialize(kindsJSON);
		}
	}


	@Override
	public JSONValue serialize(net.bluemind.system.api.DomainTemplate o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.system.api.DomainTemplate o, JSONObject ret) {

		ret.put("kinds",  new GwtSerDerUtils.ListSerDer<>(new net.bluemind.system.api.gwt.serder.DomainTemplateKindGwtSerDer()).serialize( o.kinds ));
	}

	public void serializeTo(net.bluemind.system.api.DomainTemplate o, JSONObject ret, Set<String> childPropertiesToIgnore) {

		if (!childPropertiesToIgnore.contains("kinds")) {
			ret.put("kinds",  new GwtSerDerUtils.ListSerDer<>(new net.bluemind.system.api.gwt.serder.DomainTemplateKindGwtSerDer()).serialize( o.kinds ));
		}
	}


	public Set<String> propertiesToIgnore() {
		return new HashSet<>();
	}
}
